'use strict';Object.defineProperty(exports,'__esModule',{value:true});//
//
//
//
//
//
//
//
//
//
//
//
//
//
//
//
//
//
//
//
//
//
//
//
//
//
//
//
//


var script = {
  name: 'VueStepper',
  props: {
    value: {
      type: Number,
      required: true
    },
    maxValue: {
      type: Number,
      required: false
    }, 
    minValue: {
      type: Number,
      required: false,
      default: 0
    },
    stepSize: {
      type: Number,
      required: false,
      default: 1,
      validator: function (n) { return n > 0; }
    },
    isDisabled: {
      type: Boolean,
      default: false
    },
    holdToAutoTap: {
      type: Boolean,
      default: true
    },
    autoTapRepeatIncrementMilliseconds: {
      type: Number,
      default: 250
    },
  },
  data: function data() {
    return {
      incrementTimer: undefined,
      decrementTimer: undefined,
    }
  },
  mounted: function mounted() {
    this.validateProps();
  },
  destroyed: function destroyed() {
   this.endAutoTap();
  },
  computed: {
    isIncrementDisabled: function isIncrementDisabled() {
      return this.isDisabled || this.value >= this.maxValue;
    },
    isDecrementDisabled: function isDecrementDisabled() {
      return this.isDisabled || this.value <= this.minValue;
    },
    isLastIncrementValue: function isLastIncrementValue() {
      return this.value + this.stepSize > this.maxValue; // Hint: What if maxValue is undefined? Int > undefined is always true, so this works even when `maxValue` is not set (maxValue has no default value; minValue does)
    },
    isLastDecrementValue: function isLastDecrementValue() {
      return this.value - this.stepSize < this.minValue;
    },
    stepSizeAndMaxValueConflict: function stepSizeAndMaxValueConflict() {
      return this.maxValue && (this.maxValue % this.stepSize) !== 0;
    }
  },
  methods: {
    emitIncremented: function emitIncremented() {
       this.$emit("input", this.value + this.stepSize);
    },
    emitDecremented: function emitDecremented() {
       this.$emit("input", this.value - this.stepSize);
    },
    incrementHandleMousedown: function incrementHandleMousedown() {
      var this$1 = this;

      if(!this.holdToAutoTap) { return; }
      this.incrementTimer = setInterval(function (){
        this$1.isLastIncrementValue ?
          this$1.endAutoTap() :
          this$1.emitIncremented();
      }, this.autoTapRepeatIncrementMilliseconds);
    },
    decrementHandleMousedown: function decrementHandleMousedown() {
      var this$1 = this;

      if(!this.holdToAutoTap) { return; }
      this.decrementTimer = setInterval(function (){
        this$1.isLastDecrementValue ?
          this$1.endAutoTap() :
          this$1.emitDecremented();
      }, this.autoTapRepeatIncrementMilliseconds);
    },
    endAutoTap: function endAutoTap() {
      if(this.incrementTimer) { clearInterval(this.incrementTimer); }
      if(this.decrementTimer) { clearInterval(this.decrementTimer); }
    },
    validateProps: function validateProps() {
      if(this.value < this.minValue) { throw new TypeError(("`value` (= " + (this.value) + ") may not be less than than `minValue` (= " + (this.minValue) + "). (" + (this.value) + " < " + (this.minValue) + " == " + (this.value < this.minValue) + ")")); }
      if(this.maxValue && this.maxValue < this.minValue) { throw new TypeError(("`maxValue` (= " + (this.maxValue) + ") may not be less than than `minValue` (= " + (this.minValue) + "). (" + (this.maxValue) + " < " + (this.minValue) + " == " + (this.maxValue < this.minValue) + ")")); }
      if(this.stepSizeAndMaxValueConflict) { throw new TypeError(("`maxValue` (= " + (this.maxValue) + ") must be a multiple of `stepSize` (= " + (this.stepSize) + "). (" + (this.maxValue) + " % " + (this.stepSize) + " -> " + (this.maxValue % this.stepSize) + " , should be 0)")); }
    }
  },
  watch: {
    stepSize: function stepSize() {
      this.validateProps();
    },
    maxValue: function maxValue() {
      this.validateProps();
    }
  }
};function normalizeComponent(template, style, script, scopeId, isFunctionalTemplate, moduleIdentifier /* server only */, shadowMode, createInjector, createInjectorSSR, createInjectorShadow) {
    if (typeof shadowMode !== 'boolean') {
        createInjectorSSR = createInjector;
        createInjector = shadowMode;
        shadowMode = false;
    }
    // Vue.extend constructor export interop.
    var options = typeof script === 'function' ? script.options : script;
    // render functions
    if (template && template.render) {
        options.render = template.render;
        options.staticRenderFns = template.staticRenderFns;
        options._compiled = true;
        // functional template
        if (isFunctionalTemplate) {
            options.functional = true;
        }
    }
    // scopedId
    if (scopeId) {
        options._scopeId = scopeId;
    }
    var hook;
    if (moduleIdentifier) {
        // server build
        hook = function (context) {
            // 2.3 injection
            context =
                context || // cached call
                    (this.$vnode && this.$vnode.ssrContext) || // stateful
                    (this.parent && this.parent.$vnode && this.parent.$vnode.ssrContext); // functional
            // 2.2 with runInNewContext: true
            if (!context && typeof __VUE_SSR_CONTEXT__ !== 'undefined') {
                context = __VUE_SSR_CONTEXT__;
            }
            // inject component styles
            if (style) {
                style.call(this, createInjectorSSR(context));
            }
            // register component module identifier for async chunk inference
            if (context && context._registeredComponents) {
                context._registeredComponents.add(moduleIdentifier);
            }
        };
        // used by ssr in case component is cached and beforeCreate
        // never gets called
        options._ssrRegister = hook;
    }
    else if (style) {
        hook = shadowMode
            ? function (context) {
                style.call(this, createInjectorShadow(context, this.$root.$options.shadowRoot));
            }
            : function (context) {
                style.call(this, createInjector(context));
            };
    }
    if (hook) {
        if (options.functional) {
            // register for functional component in vue file
            var originalRender = options.render;
            options.render = function renderWithStyleInjection(h, context) {
                hook.call(context);
                return originalRender(h, context);
            };
        }
        else {
            // inject component registration as beforeCreate hook
            var existing = options.beforeCreate;
            options.beforeCreate = existing ? [].concat(existing, hook) : [hook];
        }
    }
    return script;
}function createInjectorSSR(context) {
    if (!context && typeof __VUE_SSR_CONTEXT__ !== 'undefined') {
        context = __VUE_SSR_CONTEXT__;
    }
    if (!context)
        { return function () { }; }
    if (!('styles' in context)) {
        context._styles = context._styles || {};
        Object.defineProperty(context, 'styles', {
            enumerable: true,
            get: function () { return context._renderStyles(context._styles); }
        });
        context._renderStyles = context._renderStyles || renderStyles;
    }
    return function (id, style) { return addStyle(id, style, context); };
}
function addStyle(id, css, context) {
    var group =  css.media || 'default' ;
    var style = context._styles[group] || (context._styles[group] = { ids: [], css: '' });
    if (!style.ids.includes(id)) {
        style.media = css.media;
        style.ids.push(id);
        var code = css.source;
        style.css += code + '\n';
    }
}
function renderStyles(styles) {
    var css = '';
    for (var key in styles) {
        var style = styles[key];
        css +=
            '<style data-vue-ssr-id="' +
                Array.from(style.ids).join(' ') +
                '"' +
                (style.media ? ' media="' + style.media + '"' : '') +
                '>' +
                style.css +
                '</style>';
    }
    return css;
}/* script */
var __vue_script__ = script;

/* template */
var __vue_render__ = function () {var _vm=this;var _h=_vm.$createElement;var _c=_vm._self._c||_h;return _c('div',{staticClass:"stepper",on:{"mouseup":_vm.endAutoTap,"mouseout":_vm.endAutoTap,"touchend":_vm.endAutoTap,"touchcancel":_vm.endAutoTap}},[_vm._ssrNode("<button data-test-target=\"decrement\""+(_vm._ssrAttr("disabled",_vm.isDecrementDisabled))+">","</button>",[_vm._t("decrement",[_c('span',{staticClass:"minus-icon"})])],2),_vm._ssrNode(" "),_vm._ssrNode("<button data-test-target=\"increment\""+(_vm._ssrAttr("disabled",_vm.isIncrementDisabled))+">","</button>",[_vm._t("increment",[_c('span',{staticClass:"plus-icon"})])],2)],2)};
var __vue_staticRenderFns__ = [];

  /* style */
  var __vue_inject_styles__ = function (inject) {
    if (!inject) { return }
    inject("data-v-43c5e77e_0", { source: ".stepper{display:flex;flex-direction:row;justify-content:flex-start;background:#eeeeef;-webkit-user-select:none;font-size:1rem;border-radius:8px;width:fit-content}.stepper button{display:flex;flex-direction:row;border:none;position:relative;background:0 0;padding:.4rem .9rem;border-radius:0;margin:0;-webkit-appearance:none}.stepper button:hover:not(:disabled){background:#e1e1e3}.stepper button:active:not(:disabled){background:#c7c7ca}.stepper button:first-of-type{border-radius:8px 0 0 8px}.stepper button:last-of-type{border-radius:0 8px 8px 0}.stepper button:disabled{opacity:.3}.stepper button:last-of-type::before{position:absolute;left:0;content:\" \";display:block;height:60%;width:1px;background:#d6d6d9}.stepper .minus-icon{height:20px;width:20px;transform:translateY(1px);background:transparent url(\"data:image/svg+xml;base64,PD94bWwgdmVyc2lvbj0iMS4wIiBlbmNvZGluZz0iVVRGLTgiIHN0YW5kYWxvbmU9 Im5vIj8+CjwhRE9DVFlQRSBzdmcgUFVCTElDICItLy9XM0MvL0RURCBTVkcgMS4x Ly9FTiIgImh0dHA6Ly93d3cudzMub3JnL0dyYXBoaWNzL1NWRy8xLjEvRFREL3N2 ZzExLmR0ZCI+Cjxzdmcgd2lkdGg9IjEwMCUiIGhlaWdodD0iMTAwJSIgdmlld0Jv eD0iMCAwIDMwIDMiIHZlcnNpb249IjEuMSIgeG1sbnM9Imh0dHA6Ly93d3cudzMu b3JnLzIwMDAvc3ZnIiB4bWxuczp4bGluaz0iaHR0cDovL3d3dy53My5vcmcvMTk5 OS94bGluayIgeG1sOnNwYWNlPSJwcmVzZXJ2ZSIgeG1sbnM6c2VyaWY9Imh0dHA6 Ly93d3cuc2VyaWYuY29tLyIgc3R5bGU9ImZpbGwtcnVsZTpldmVub2RkO2NsaXAt cnVsZTpldmVub2RkO3N0cm9rZS1saW5lY2FwOnJvdW5kO3N0cm9rZS1saW5lam9p bjpyb3VuZDtzdHJva2UtbWl0ZXJsaW1pdDoxLjU7Ij4KICAgIDxnIHRyYW5zZm9y bT0ibWF0cml4KDEsMCwwLDEsLTE3OC44NCwtNzcuNjg0NikiPgogICAgICAgIDxn IHRyYW5zZm9ybT0ibWF0cml4KDEuMDM2MDUsMCwwLDEsLTUuMTY1NCwtNjkuNjI2 NikiPgogICAgICAgICAgICA8cGF0aCBkPSJNMTc5LjA1MSwxNDguODExTDIwNC45 NDIsMTQ4LjgxMSIgc3R5bGU9ImZpbGw6bm9uZTtzdHJva2U6YmxhY2s7c3Ryb2tl LXdpZHRoOjIuOTVweDsiLz4KICAgICAgICA8L2c+CiAgICA8L2c+Cjwvc3ZnPgo=\") no-repeat center center}.stepper .plus-icon{height:18px;width:18px;margin-top:1px;margin-bottom:1px;background:transparent url(\"data:image/svg+xml;base64,PD94bWwgdmVyc2lvbj0iMS4wIiBlbmNvZGluZz0iVVRGLTgiIHN0YW5kYWxvbmU9 Im5vIj8+CjwhRE9DVFlQRSBzdmcgUFVCTElDICItLy9XM0MvL0RURCBTVkcgMS4x Ly9FTiIgImh0dHA6Ly93d3cudzMub3JnL0dyYXBoaWNzL1NWRy8xLjEvRFREL3N2 ZzExLmR0ZCI+Cjxzdmcgd2lkdGg9IjEwMCUiIGhlaWdodD0iMTAwJSIgdmlld0Jv eD0iMCAwIDI5IDI4IiB2ZXJzaW9uPSIxLjEiIHhtbG5zPSJodHRwOi8vd3d3Lncz Lm9yZy8yMDAwL3N2ZyIgeG1sbnM6eGxpbms9Imh0dHA6Ly93d3cudzMub3JnLzE5 OTkveGxpbmsiIHhtbDpzcGFjZT0icHJlc2VydmUiIHhtbG5zOnNlcmlmPSJodHRw Oi8vd3d3LnNlcmlmLmNvbS8iIHN0eWxlPSJmaWxsLXJ1bGU6ZXZlbm9kZDtjbGlw LXJ1bGU6ZXZlbm9kZDtzdHJva2UtbGluZWNhcDpyb3VuZDtzdHJva2UtbGluZWpv aW46cm91bmQ7c3Ryb2tlLW1pdGVybGltaXQ6MS41OyI+CiAgICA8ZyB0cmFuc2Zv cm09Im1hdHJpeCgxLDAsMCwxLC0yNzIuMzk3LC02NS4yMjI0KSI+CiAgICAgICAg PGcgdHJhbnNmb3JtPSJtYXRyaXgoMSwwLDAsMSwwLC02OS44OTg0KSI+CiAgICAg ICAgICAgIDxnIHRyYW5zZm9ybT0ibWF0cml4KDAuOTY2MTM4LDAsMCwxLDEwMC45 MDksMC4yNzE3OTQpIj4KICAgICAgICAgICAgICAgIDxwYXRoIGQ9Ik0xNzkuMDUx LDE0OC44MTFMMjA0Ljk0MiwxNDguODExIiBzdHlsZT0iZmlsbDpub25lO3N0cm9r ZTpibGFjaztzdHJva2Utd2lkdGg6My4wNXB4OyIvPgogICAgICAgICAgICA8L2c+ CiAgICAgICAgICAgIDxnIHRyYW5zZm9ybT0ibWF0cml4KDUuODk0NzRlLTE3LC0w Ljk2MjY4NSwxLDYuMTIzMjNlLTE3LDEzNy41OTMsMzMzLjkxNSkiPgogICAgICAg ICAgICAgICAgPHBhdGggZD0iTTE3OS4wNTEsMTQ4LjgxMUwyMDQuOTQyLDE0OC44 MTEiIHN0eWxlPSJmaWxsOm5vbmU7c3Ryb2tlOmJsYWNrO3N0cm9rZS13aWR0aDoz LjA2cHg7Ii8+CiAgICAgICAgICAgIDwvZz4KICAgICAgICA8L2c+CiAgICA8L2c+ Cjwvc3ZnPgo=\") no-repeat center center}", map: undefined, media: undefined });

  };
  /* scoped */
  var __vue_scope_id__ = undefined;
  /* module identifier */
  var __vue_module_identifier__ = "data-v-43c5e77e";
  /* functional template */
  var __vue_is_functional_template__ = false;
  /* style inject shadow dom */
  

  
  var __vue_component__ = normalizeComponent(
    { render: __vue_render__, staticRenderFns: __vue_staticRenderFns__ },
    __vue_inject_styles__,
    __vue_script__,
    __vue_scope_id__,
    __vue_is_functional_template__,
    __vue_module_identifier__,
    false,
    undefined,
    createInjectorSSR,
    undefined
  );// Import vue component

// install function executed by Vue.use()
function install(Vue) {
  if (install.installed) { return; }
  install.installed = true;
  Vue.component('VueNumberStepper', __vue_component__);
}

// Create module definition for Vue.use()
var plugin = {
  install: install,
};

// To auto-install when vue is found
/* global window global */
var GlobalVue = null;
if (typeof window !== 'undefined') {
  GlobalVue = window.Vue;
} else if (typeof global !== 'undefined') {
  GlobalVue = global.Vue;
}
if (GlobalVue) {
  GlobalVue.use(plugin);
}

// Inject install function into component - allows component
// to be registered via Vue.use() as well as Vue.component()
__vue_component__.install = install;

// It's possible to expose named exports when writing components that can
// also be used as directives, etc. - eg. import { RollupDemoDirective } from 'rollup-demo';
// export const RollupDemoDirective = component;
exports.default=__vue_component__;